#!/bin/bash

# Set environment variables and call do-*.sh in sequence

[ -z "$WEBDIR" ] && export WEBDIR=~/www/kdocs
[ -z "$LNXDIR" ] && export LNXDIR=~/linux

source "$WEBDIR"/make/functions.sh

# Update mercurial repository
if [ "$1" != "--nonet" ]
then
  echo "Update Linux source from mercurial on kernel.org"
  get_hg || exit 1
fi

echo "Install updated (and patched) Documentation directory."
update_documentation_dir || exit 1

echo "Set up Linux build directory (uses patched Documentation dir)"
setuplinuxtemp || exit 1

if [ "$1" == "--long" ]
then
  # I have a dual processor laptop, so overlap work here.  Have make htmldocs
  # produce split-up versions in the background (which is very slow)
  # while other work is done in the foreground.
  make_htmldocs > /dev/null &

  # This is also very slow.

  # Search for references to RFC documents
  "$WEBDIR"/make/do-rfc.sh &
fi

echo "Update master index."
update_master || exit 1

echo "Mirror resources"
mirror_files || exit 1

echo Copy readme files from Linux kernel
find_readmes || exit 1

echo Convert kconfig to html for all architectures
htmlize_menuconfig || exit 1

echo Build nochunks htmldocs.
make_htmlnochunks || exit 1

# Wait for background task(s) to finish.  If there aren't any, this continues
# immediately.
"$WEBDIR"/do-wait.sh

# Install the htmldocs
install_htmldocs || exit 1

# Search for references to RFC documents
"$WEBDIR"/make/do-rfc.sh > "$WEBDIR"/rfc-linux.html || exit 1

echo "Done with kdocs"
